.. _Python2_support:

Python 2 Support
================

.. rubric:: Python 2 and *pydicom*

*pydicom* dropped support for Python 2 following the 1.4.X versions.

* pydicom v2.0 (planned for ~April 2020) will be Python 3.5+ only
* pydicom v2.1 (no date set) will be Python 3.6+

We may consider the possibility of backporting some fixes to *pydicom* v1.4 for
very serious issues, if users make the case for it.  Generally speaking,
however, we encourage all *pydicom* users to make the transition to Python 3 by
early 2020.
